pub struct StubKeyIdMapper {
pub(crate) map: Arc<BiMap<OffchainPublicKey, HoprKeyIdent>>,
}Expand description
Bidirectional mapping between [HoprKeyIdent] and [OffchainPublicKey].
Extracted from the test helper in transport/path/src/planner.rs.
Fields
map: Arc<BiMap<OffchainPublicKey, HoprKeyIdent>>Trait Implementations
Sourceimpl Clone for StubKeyIdMapper
impl Clone for StubKeyIdMapper
Sourcefn clone(&self) -> StubKeyIdMapper
fn clone(&self) -> StubKeyIdMapper
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl KeyIdMapping<KeyIdent, OffchainPublicKey> for StubKeyIdMapper
impl KeyIdMapping<KeyIdent, OffchainPublicKey> for StubKeyIdMapper
Sourcefn map_key_to_id(&self, key: &OffchainPublicKey) -> Option<HoprKeyIdent>
fn map_key_to_id(&self, key: &OffchainPublicKey) -> Option<HoprKeyIdent>
Maps public key to its unique identifier.
Sourcefn map_id_to_public(&self, id: &HoprKeyIdent) -> Option<OffchainPublicKey>
fn map_id_to_public(&self, id: &HoprKeyIdent) -> Option<OffchainPublicKey>
Maps public key identifier to the actual public key.
fn map_keys_to_ids(&self, keys: &[K]) -> Vec<Option<Id>>
fn map_keys_to_ids(&self, keys: &[K]) -> Vec<Option<Id>>
Convenience method to map a slice of public keys to IDs.
fn map_ids_to_keys(&self, ids: &[Id]) -> Vec<Option<K>>
fn map_ids_to_keys(&self, ids: &[Id]) -> Vec<Option<K>>
Convenience method to map a slice of IDs to public keys.